| append_md | R Documentation |
Append metadata to DNAm data compilations. Handles metadata addition for either HDF5 or HDF5-SummarizedExperiment compilation files.
append_md(
ts,
files.dname = "recount-methylation-files",
md.dname = "metadata",
comp.dname = "compilations",
comp.fnv = c(".*_h5_.*", ".*_h5se_.*"),
mdall.fnstr = "mdall_*",
verbose = TRUE
)
ts |
Timestamp. |
files.dname |
Files dir name for the instance ("recount-methylation-files") |
md.dname |
Metadata dir name for the instance ("metadata"), contained in files.dname. |
comp.dname |
Compilations dir name for instance ("compilations"), contained in files.dname. |
comp.fnv |
Vector of regular expression patterns to filter compilation files list. |
mdall.fnstr |
Filename string stem to detect aggregate metadata table at md.dname. |
verbose |
Whether to show status messages (TRUE). |
NULL, if all appends successful, otherwise a list of the compilation files for which appends weren't successful.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.