| dtables_rg | R Documentation |
Generates 2-channel signal data tables. Validates IDATs, handles new paths and data.table options, and provides verbose input from main for loop to write data.
dtables_rg(
platform = c("hm450k", "epic"),
version,
ts,
verbose = TRUE,
gsmint = 60,
overwrite = TRUE,
fnstem = "mdat.compilation",
sepval = " ",
idatspath = file.path("recount-methylation-files", "idats"),
destpath = file.path("recount-methylation-files", "compilations")
)
platform |
The DNAm array platform of files to read/write (either "hm450k" or "epic"). |
version |
Version of the run for data table filenames. |
ts |
NTP timestamp integer, for filenames (see get_metadata function). |
verbose |
Whether to return verbose notifications. |
gsmint |
Number of GSMs to process at a time, typically runs best near 50 samples. |
overwrite |
Whether to overwrite existing data.table files with same destpath (default TRUE). |
fnstem |
Filename stem for data tables. |
sepval |
Separator symbol for data being written (default " "). |
idatspath |
Path to IDAT files to read. |
getnb |
Whether to get noob-normalized Beta-vlaues (default: FALSE). |
NULL, writes new data tables from IDATs using 'dt_write_rg()'.
#version = "0.0.1"
#timestamp = get_metadata("title", version)[["timestamp"]]
#dtables_rg(version = version, timestamp = timestamp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.