| get_filt | R Documentation |
Does pattern matching for regex patterns constructed from a character string or vector of such character strings.
get_filt(
v,
m = mdpre,
filtrel = "|",
ntfilt = NULL,
ptfilt = NULL,
varl = c("gsm_title", "sample_type", "disease_state", "anatomic_location", "misc")
)
v |
Character string or vector of such strings. |
m |
Preprocessed metadata used for pattern matching/lookups (data.frame, mdpre). |
filtrel |
Logical symbol joining each regex pattern (default "|"). |
ntfilt |
Regex pattern corresponding to negative lookup filter (default NULL). |
ptfilt |
Regex pattern corresponding to positive lookup filter (default NULL). |
The result of assessing a regex match on a metadata variable.
appendvar
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.