| make_h5_gm | R Documentation |
Makes an HDF5 db file with raw/unnormalized methylated and unmethylated signal, including rows and columns as datasets.
make_h5_gm(
dbn,
version,
ts,
blocksize = 65,
files.dname = "recount-methylation-files",
comp.dname = "compilations",
platform = c("hm450k", "epic"),
newfnstem = "remethdb",
verbose = TRUE,
dsv = c("meth", "unmeth"),
replace.opt = TRUE
)
dbn |
Path to the RGChannelSet H5SE data directory. |
version |
Version for new h5 file. |
ts |
Timestamp for new h5 file. |
blocksize |
Size of blocks/number of samples to process at a time (default 65). |
files.dname |
Files dir name for instance ("recount-methylation-files") |
comp.dname |
Compilations dir name, located in files.dname |
platform |
Array platform (either "hm450k" or "epic"). |
newfnstem |
New filename stem for h5 file. |
verbose |
Whether to return verbose messages (default TRUE). |
dsv |
Vector of new datasets to add to h5 HDF5 database. |
replace.opt |
Whether to replace h5 files with duplicate filename (default TRUE). |
Path to new HDF5 object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.