| make_h5db_rg | R Documentation |
Make and populate a new HDF5 database with red and green signal, and metadata
make_h5db_rg(
dbfnstem,
dbpath,
version,
ts,
fnpath,
platform = c("hm450k", "epic"),
fnl,
dsnl = c("redsignal", "greensignal"),
rmoldh5 = TRUE,
newtables = FALSE,
mdpath = NULL,
ngsm.block = 50,
verbose = TRUE
)
dbfnstem |
Stem of filename for h5 database (to which ts and version appended) |
dbpath |
Database file path to write to. |
version |
Version of new database file. |
ts |
Timestamp of new database file. |
fnpath |
Path to dir containing files in fnl. |
platform |
DNAm array platform for instance. |
fnl |
Vector of signal tables containing data to be added. |
dsnl |
Vector of new h5 data set objects in the h5db object, corresponding (1:1) to the files declared in fnl. |
newtables |
Whether to also add new data tables (noob-norm. Beta-values, meth. and unmeth. signal). |
mdpath |
If addmd, the path to the metadata file to load. |
ngsm.block |
Number of GSMs (samples) per process block (default 50, passed to 'h5_newtables()'). |
verbose |
Whether to show verbose status updates. |
Populates the HDF5 database
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.