| md_agg | R Documentation |
Detects valid metadata at md.dpath, then aggregates these into a single composite table.
md_agg(
ts = NULL,
platform = NULL,
lfn = NULL,
id.cname = "gsm",
mda.fn = "mdall",
md.fnv = c("^md_postprocess.*", "^mdmod_dnam-predictions_.*", "^mdqc_.*",
"^mdrep_.*", "^md_msrapout_.*", "gsm_jsontitledf_.*"),
md.dpath = file.path("recount-methylation-files", "metadata"),
verbose = TRUE
)
ts |
Timestamp. |
platform |
The DNAm array platform used. |
lfn |
Optional list of filenames. If NULL, automatically detect valid metadata files (NULL). |
id.cname |
Column name for sample IDs, which should be present in each table to be compiled ("gsm"). |
mda.fn |
Filename stem of new aggregate metadata table to save ("mdall"). |
md.fnv |
Vector of regex patterns to detect valid metadata tables. |
md.dpath |
Path to metadata directory. |
verbose |
Whether to show status messages (TRUE). |
NULL, stores aggregate/composite metadata table.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.